@@ -207,7 +207,7 @@ class VisualizationFunctions:
 
         return
     
-    def makeMarkerExpressionPlot(self, dpi = 300, extension = 'png'):
+    def makeMarkerExpressionPlot(self, fontscale = 0.75, dpi = 300, extension = 'png'):
 
         '''Produce image on marker genes and their expression on all clusters.
         Uses files generated by function DCS.Vote
@@ -320,13 +320,13 @@ class VisualizationFunctions:
             clusterNames = list(votingResults.values())
             clusterIndices = list(votingResults.keys())
 
-            ax.set_yticklabels(['Mean'] + [str(clusterNames[i]) + ' (' + str(clusterIndices[i]) + ')' for i in ORDER], rotation=0, fontsize=8)
+            ax.set_yticklabels(['Mean'] + [str(clusterNames[i]) + ' (' + str(clusterIndices[i]) + ')' for i in ORDER], rotation=0, fontsize=8*fontscale)
             ax.set_xlim([-0.5,X_markers_cluster_means_transpose.shape[1] - 0.5])
             ax.set_ylim([-0.5,X_markers_cluster_means_transpose.shape[0] + 1 - 0.5])
 
         if True:
             ax2 = plt.subplot(gs[1])
-            fontsize = 5
+            fontsize = 5*fontscale
             cells_in_clusters = df_votingResults['# cells in cluster'].values.copy()[ORDER]
             numberOfCells = cells_in_clusters.sum()
 
@@ -366,8 +366,8 @@ class VisualizationFunctions:
             for i in range(0,len(xtickslabels),2):
                 xtickslabels[i] += " ─────────"
 
-            ax3.set_xticklabels(xtickslabels, rotation=90, fontsize=5)
-            ax3.set_yticklabels(df_markers_weighted.index.values, rotation=0, fontsize=8)
+            ax3.set_xticklabels(xtickslabels, rotation=90, fontsize=5*fontscale)
+            ax3.set_yticklabels(df_markers_weighted.index.values, rotation=0, fontsize=8*fontscale)
 
             ax3.set_xlim([-0.5, df_markers_weighted.shape[1] - 0.5])
             ax3.set_ylim([-0.5, df_markers_weighted.shape[0] - 0.5])
@@ -1674,7 +1674,7 @@ class VisualizationFunctions:
 
         return dict(zip(labels, list(sets)))
 
-    def makeHopfieldPCplot(self, colormap = cm.hot_r, plotTrLines = False, clusterid = 1, trID = 0, axisOff = False, trPath = None, dpi = 300, extension = 'png'):
+    def makeHopfieldPCplot(self, colormap = cm.hot_r, plotTrLines = False, clusterid = 1, trID = 0, axisOff = False, fontscale = 1., trPath = None, dpi = 300, extension = 'png'):
 
         '''Make radar plot of the attractors in their principal components coordinates
 
@@ -1751,11 +1751,12 @@ class VisualizationFunctions:
 
             color = cm.jet(i/len(attrs_names))
 
-            ax.plot(angles, values, color=color, linewidth=1.0, linestyle='solid', label=celltype)
-            #ax.fill(angles, values, alpha=0.2, color=color)
+            ax.plot(angles, values, color=color, linewidth=1.75, linestyle='solid', label=celltype)
+            #ax.fill(angles, values, alpha=0.2, color=color, zorder=1)
+            ax.fill_between(angles, 0, values, alpha=0.2, facecolor=color)
 
-            temp_texts = ax.text(angles[np.argmax(values)], values[np.argmax(values)], celltype, color=color, fontsize=10, ha='center', va='center')
-            temp_texts.set_path_effects([path_effects.Stroke(linewidth=0.5, foreground='k'), path_effects.Normal()])
+            temp_texts = ax.text(angles[np.argmax(values)], values[np.argmax(values)], celltype, color=color, fontsize=12.*fontscale, ha='center', va='center')
+            temp_texts.set_path_effects([path_effects.Stroke(linewidth=1., foreground='k'), path_effects.Normal()])
 
         if plotTrLines:
             trajectories = read(os.path.join(trPath, 'trajectories%s')%(trID))
@@ -1801,8 +1802,19 @@ class VisualizationFunctions:
             suffix = 'attractors'
 
         for i, pc in enumerate(df.columns):
-            temp_texts = ax.text(angles[i], 1.1 * (vmax - vmin) + vmin, pc, color='k', fontsize=14, ha='center', va='center')
-            temp_texts.set_path_effects([path_effects.Stroke(linewidth=0.5, foreground='w'), path_effects.Normal()])
+            temp_texts = ax.text(angles[i], 1.15 * (vmax - vmin) + vmin, pc, color='k', fontsize=14*fontscale, ha='center', va='center')
+            temp_texts.set_path_effects([path_effects.Stroke(linewidth=0.5*fontscale, foreground='w'), path_effects.Normal()])
+
+        ax.set_axisbelow(True)
+
+        #ax.plot(angles, [0]*len(angles), color='k', linewidth=1., linestyle='-', label=celltype)
+
+        fig.canvas.draw()
+        ylabels = ax.get_yticklabels()
+        ax.set_yticklabels([])
+
+        for label in ylabels:
+            ax.text(label._x, label._y, label._text, zorder=np.inf)
 
         self.saveFigure(fig, self.saveDir, self.dataName + '_polar_%s'%(suffix), extension=extension, dpi=dpi)
 
@@ -1926,6 +1938,14 @@ class VisualizationFunctions:
             xmin, xmax = mesh2D.T[0].min(), mesh2D.T[0].max()
             ymin, ymax = mesh2D.T[1].min(), mesh2D.T[1].max()
 
+            dx = (xmax - xmin) * 0.05
+            dy = (ymax - ymin) * 0.05
+
+            xmin -= dx
+            xmax += dx
+            ymin -= dy
+            ymax += dy
+
             ngrid = 100
             grid = np.zeros((ngrid + 1, ngrid + 1))
             grid[:] = vmin
@@ -1947,16 +1967,18 @@ class VisualizationFunctions:
             xgrid = np.linspace(xmin, xmax, num=(ngrid+1))
             ygrid = np.linspace(ymin, ymax, num=(ngrid+1))
 
-            tempColormap = matplotlib.colors.LinearSegmentedColormap.from_list('cmap', [(0.75, 0.75, 0.75), (0, 1, 1), (0, 0, 1), (1, 0, 0)], N=1000)
+            tempColormap = colormap
+            #tempColormap = matplotlib.colors.LinearSegmentedColormap.from_list('cmap', [(0.75, 0.75, 0.75), (0, 1, 1), (0, 0, 1), (1, 0, 0)], N=1000)
 
-            ax.contour(xgrid, ygrid, data, levels=10, cmap=tempColormap, linewidths=0.5, zorder=-10**8+1)
+            ax.contour(xgrid, ygrid, data, levels=10, cmap=tempColormap, linewidths=1.0, zorder=-10**8+1)
+            ax.contour(xgrid, ygrid, data, levels=10, colors='k', linestyles='solid', linewidths=0.25, zorder=-10**8+2)
     
         if plotAttractors:
             texts = []
 
             ax.plot(attrs2D.T[0], attrs2D.T[1], '*', ms=14, color='k', alpha=1.0, zorder=-10**7, clip_on=False)
             for attr in range(attrs2D.T[0].shape[0]):
-                temp_texts = ax.text(attrs2D.T[0][attr], attrs2D.T[1][attr], attrs_names[attr], fontsize=10, ha='left',va='center', zorder=10 ** 10, clip_on=False)
+                temp_texts = ax.text(attrs2D.T[0][attr], attrs2D.T[1][attr], attrs_names[attr], fontsize=fontsize, ha='left',va='center', zorder=10 ** 10, clip_on=False)
                 temp_texts.set_path_effects([path_effects.Stroke(linewidth=1, foreground='white'), path_effects.Normal()])
                 texts.append(temp_texts)
 
